fbchat\_muqit.User
==================

.. currentmodule:: fbchat_muqit

.. autoclass:: User

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~User.__copy__
      ~User.__delattr__
      ~User.__dir__
      ~User.__eq__
      ~User.__format__
      ~User.__ge__
      ~User.__getattribute__
      ~User.__getstate__
      ~User.__gt__
      ~User.__hash__
      ~User.__init__
      ~User.__init_subclass__
      ~User.__le__
      ~User.__lt__
      ~User.__ne__
      ~User.__new__
      ~User.__reduce__
      ~User.__reduce_ex__
      ~User.__replace__
      ~User.__repr__
      ~User.__rich_repr__
      ~User.__setattr__
      ~User.__sizeof__
      ~User.__str__
      ~User.__subclasshook__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~User.alternate_name
      ~User.first_name
      ~User.gender
      ~User.id
      ~User.image
      ~User.is_blocked
      ~User.is_friend
      ~User.name
      ~User.url
      ~User.username
      ~User.__annotations__
      ~User.__doc__
      ~User.__module__
      ~User.__slots__
      ~User.__struct_config__
      ~User.__struct_defaults__
      ~User.__struct_encode_fields__
      ~User.__struct_fields__
   
   